@@ -2,17 +2,19 @@ package shortcuts
 
 import (
 	"errors"
+	"os"
+	"strings"
 
-	"github.com/linuxdeepin/go-dbus-factory/com.deepin.wm"
-	"pkg.deepin.io/dde/daemon/keybinding/util"
+	wm "github.com/linuxdeepin/go-dbus-factory/com.deepin.wm"
+	"github.com/linuxdeepin/dde-daemon/keybinding/util"
 )
 
 type kWinShortcut struct {
 	BaseShortcut
-	wm *wm.Wm
+	wm wm.Wm
 }
 
-func newKWinShortcut(id, name string, keystrokes []string, wm *wm.Wm) *kWinShortcut {
+func newKWinShortcut(id, name string, keystrokes []string, wm wm.Wm) *kWinShortcut {
 	return &kWinShortcut{
 		BaseShortcut: BaseShortcut{
 			Id:         id,
@@ -31,6 +33,22 @@ func (ks *kWinShortcut) ReloadKeystrokes() bool {
 		logger.Warningf("failed to get accel for %s: %v", ks.Id, err)
 		return false
 	}
+	sessionType := os.Getenv("XDG_SESSION_TYPE")
+	if strings.Contains(sessionType, "wayland") {
+		if len(keystrokes) != 0 && strings.Contains(keystrokes[0], "SysReq") {
+			keystrokes[0] = strings.Replace(keystrokes[0], "SysReq", "<Alt>Print", 1)
+		}
+		//launcher
+		if ks.Id == "launcher" {
+			keystrokes[0] = "<Super_L>"
+		}
+		//system-monitor
+		if ks.Id == "system-monitor" {
+			for i := 0; i < len(keystrokes); i++ {
+				keystrokes[i] = strings.Replace(keystrokes[i], "Esc", "Escape", 1)
+			}
+		}
+	}
 	newVal := ParseKeystrokes(keystrokes)
 	ks.setKeystrokes(newVal)
 	return !keystrokesEqual(oldVal, newVal)
