@@ -9,6 +9,7 @@ import (
 	dbus "github.com/godbus/dbus"
 	"github.com/linuxdeepin/dde-daemon/loader"
 	"github.com/linuxdeepin/dde-daemon/network/nm"
+	airplanemode "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.airplanemode"
 	networkmanager "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.networkmanager"
 	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/dbusutil/proxy"
@@ -98,6 +99,7 @@ type Network struct {
 	nmManager  networkmanager.Manager
 	nmSettings networkmanager.Settings
 	sigLoop    *dbusutil.SignalLoop
+	airplane   airplanemode.AirplaneMode
 
 	// nolint
 	signals *struct {
@@ -112,6 +114,8 @@ func (n *Network) init() error {
 	sysBus := n.service.Conn()
 	n.sigLoop = dbusutil.NewSignalLoop(sysBus, 10)
 	n.sigLoop.Start()
+	// airplane
+	n.airplane = airplanemode.NewAirplaneMode(sysBus)
 	n.nmManager = networkmanager.NewManager(sysBus)
 	n.nmSettings = networkmanager.NewSettings(sysBus)
 	// retry get all devices
@@ -563,6 +567,14 @@ func (n *Network) enableWireless() error {
 		return nil
 	}
 
+	// 飞行模式开启，不激活wifi
+	if v, err := n.airplane.WifiEnabled().Get(0); err != nil {
+		logger.Warning(err)
+	} else if v {
+		logger.Debug("disable wifi because airplane mode is on")
+		return nil
+	}
+
 	return n.nmManager.WirelessEnabled().Set(0, true)
 }
 
